@@ -11,5 +11,5 @@ class BasicUsageTest(unittest.TestCase):
     def test_simplest_case(self):
         """Try initialising a client and get live values."""
         client = SolMateAPIClient("test1")
-        client.connect("token")
+        client.quickstart()
         print(f"Current live values of your SolMate: {client.get_live_values()}")
